@@ -5,6 +5,8 @@ import pandas as pd
 
 from vnpy_mongodb import Database
 
+from vnpy.trader.constant import Exchange, Interval
+
 
 class JoMongodbDatabase(Database):
 
@@ -17,31 +19,34 @@ class JoMongodbDatabase(Database):
 
     def load_bar_df(
             self,
-            symbol: str, exchange: str, interval: str,
-            start: datetime.date = None,
-            end: datetime.date = None,
+            symbol: str,
+            exchange: Exchange,
+            interval: Interval,
+            start: datetime = None,
+            end: datetime = None,
             table: str = None,
     ) -> pd.DataFrame:
 
-        datetime_start = {"$gte": datetime(start.year, start.month, start.day)} if start else {}
-        datetime_end = {"$lte": datetime(end.year, end.month, end.day)} if end else {"$lte": datetime.now()}
+        datetime_start = {"$gte": start} if start else {}
+        datetime_end = {"$lte": end} if end else {"$lte": datetime.now()}
 
         db = self.client[self.database]
         collection = db[table] if table is not None else db[self.bar_collection_name]
         query = (
             {
-                "symbol": symbol, "exchange": exchange, "interval": interval,
+                "symbol": symbol, "exchange": exchange.value, "interval": interval.value,
                 "datetime": {**datetime_start, **datetime_end}
             },
             {'_id': 0}
         )
 
-        df = pd.json_normalize(list(collection.find(*query)))
-
-        return df
+        return pd.json_normalize(list(collection.find(*query)))
 
     def save_bar_df(self, df, table: str = None, callback=None):
         '''
+        df的datetime如果没有tzinfo, 为了统一, 最好设置一下,
+        例如: df['datetime'] = df['datetime'].tz_localize(DB_TZ)
+
         :param df:
         :param table: 可以指定新的表名, 进行分表存储, 替代默认的 "bar_data"
         :param callback: 用于回显当前存储进度
@@ -74,32 +79,39 @@ class JoMongodbDatabase(Database):
             if callback is not None:
                 callback(n_rows, start_i)
 
+        symbol = my_list[0]["symbol"]
+        exchange = my_list[0]["exchange"]
+        interval = my_list[0]["interval"]
+
         # 更新汇总
         overview_filter = {
-            "symbol": my_list[0]["symbol"],
-            "exchange": my_list[0]["exchange"],
-            "interval": my_list[0]["interval"]
+            "symbol": symbol,
+            "exchange": exchange,
+            "interval": interval
         }
 
         overview = self.overview_collection.find_one(overview_filter)
 
+        start_datetime = my_list[0]["datetime"].to_pydatetime()
+        end_datetime = my_list[-1]["datetime"].to_pydatetime()
+
         if not overview:
             overview = {
-                "symbol": my_list[0]["symbol"],
-                "exchange": my_list[0]["exchange"],
-                "interval": my_list[0]["interval"],
+                "symbol": symbol,
+                "exchange": exchange,
+                "interval": interval,
                 "count": len(my_list),
-                "start": my_list[0]["datetime"],
-                "end": my_list[-1]["datetime"]
+                "start": start_datetime,
+                "end": end_datetime
             }
         else:
-            overview["start"] = min(my_list[0]["datetime"], overview["start"])
-            overview["end"] = max(my_list[-1]["datetime"], overview["end"])
+            overview["start"] = min(start_datetime, overview["start"])
+            overview["end"] = max(end_datetime, overview["end"])
 
             # TODO 这里以后注意分表的时候, 数据量的更新问题
             overview["count"] = self.bar_collection.count_documents(overview_filter)
 
-        self.overview_collection.update_one(overview_filter, overview, upsert=True)
+        self.overview_collection.update_one(overview_filter, {"$set": overview}, upsert=True)
         return True
 
     def get_groupby_df(self, table: str = None) -> pd.DataFrame:
@@ -126,7 +138,7 @@ class JoMongodbDatabase(Database):
             }
         )
 
-    def get_end_date(self, symbol, exchange, interval) -> np.datetime64:
+    def get_end_date(self, symbol: str, exchange: Exchange, interval: Interval) -> np.datetime64:
         # sql = f'''select * from dbbardata
         #  where symbol='{symbol}' and exchange='{exchange}' and interval='{interval}'
         #  order by datetime desc limit 1;
@@ -135,7 +147,7 @@ class JoMongodbDatabase(Database):
         df = self.get_sorted_date_df(symbol, exchange, interval, ascend=False)
         return df['datetime'].values[0]
 
-    def get_start_date(self, symbol, exchange, interval) -> np.datetime64:
+    def get_start_date(self, symbol: str, exchange: Exchange, interval: Interval) -> np.datetime64:
         #  sql = f'''select * from dbbardata
         #  where symbol='{symbol}' and exchange='{exchange}' and interval='{interval}'
         #  order by datetime asc limit 1;
@@ -143,14 +155,15 @@ class JoMongodbDatabase(Database):
         df = self.get_sorted_date_df(symbol, exchange, interval, ascend=True)
         return df['datetime'].values[0]
 
-    def get_sorted_date_df(self, symbol, exchange, interval, ascend=True, table: str = None) -> pd.DataFrame:
+    def get_sorted_date_df(self, symbol: str, exchange: Exchange, interval: Interval, ascend=True,
+                           table: str = None) -> pd.DataFrame:
 
         ascend = 1 if ascend else -1
 
         db = self.client[self.database]
         collection = db[self.bar_collection_name] if table is None else db[table]
         query = (
-            {"symbol": symbol, "exchange": exchange, "interval": interval},
+            {"symbol": symbol, "exchange": exchange.value, "interval": interval.value},
             {'_id': 0}
         )
 
@@ -162,13 +175,14 @@ class JoMongodbDatabase(Database):
 
 
 if __name__ == '__main__':
-    symbol, exchange, interval = "ethbtc", "BINANCE", "d"
+    symbol, exchange, interval = "RBL8", Exchange.SHFE, Interval.MINUTE_5
     dd = JoMongodbDatabase()
 
     start_date = dd.get_start_date(symbol, exchange, interval)
     end_date = dd.get_end_date(symbol, exchange, interval)
     grb_df = dd.get_groupby_df()
     df = dd.load_bar_df(symbol, exchange, interval)
+
     # dd.save_bar_df(df)
 
     print(1)
